==> Rttf2pt1_1.3.13.tar.gz: Rttf2pt1/README.md <==
# Foreword

The Rttf2pt1 R package was created and maintained by [Winston Chang](https://github.com/wch) on [github](https://github.com/wch/Rttf2pt1) for more than 13 years with a first commit on github the 11th of june 2012.
The previous commit history of the package can be found [here](https://github.com/wch/Rttf2pt1).
The responsibilities and attention of Winston Chang are on things quite far away from extrafont and Rttf2pt1 these days. 
As a consequence he asked for another person to maintain the Rttf2pt1 package and I ([Frederic Bertrand](https://github.com/fbertran)) volunteered [(read here)](https://github.com/wch/Rttf2pt1/issues/25#issuecomment-3320579566).

The following text is an update the original [README.md](https://github.com/wch/Rttf2pt1/blob/main/README.md) from Winston Chang repository on [github](https://github.com/wch/Rttf2pt1).

-------------------------


<!-- badges: start -->
[![R-CMD-check](https://github.com/fbertran/Rttf2pt1/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/fbertran/Rttf2pt1/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

# Rttf2pt1

The Rttf2p1 package for R is meant to be used with the [extrafont](https://github.com/fbertran/extrafont) package.

This package contains the utility program `ttf2pt1`, and is in its own package for licensing reasons.
It will be compiled on installation, so you need a build environment on your system.

# Licensing notes

This product includes software developed by the TTF2PT1 Project and its contributors.

==> Rttf2pt1_1.3.14.tar.gz: Rttf2pt1/README.md <==
# Foreword

The Rttf2pt1 R package was created and maintained by [Winston Chang](https://github.com/wch) on [github](https://github.com/wch/Rttf2pt1) for more than 13 years with a first commit on github the 11th of june 2012.
The previous commit history of the package can be found [here](https://github.com/wch/Rttf2pt1).
The responsibilities and attention of Winston Chang are on things quite far away from extrafont and Rttf2pt1 these days. 
As a consequence he asked for another person to maintain the Rttf2pt1 package and I ([Frederic Bertrand](https://github.com/fbertran)) volunteered [(read here)](https://github.com/wch/Rttf2pt1/issues/25#issuecomment-3320579566).

The following text is an update the original [README.md](https://github.com/wch/Rttf2pt1/blob/main/README.md) from Winston Chang repository on [github](https://github.com/wch/Rttf2pt1).

**2025-09-24: Rttf2pt1 is back to CRAN.**


-------------------------

# Rttf2pt1

<https://doi.org/10.32614/CRAN.package.Rttf2pt1>

The Rttf2p1 package for R is meant to be used with the [extrafont](https://github.com/fbertran/extrafont) package.

This package contains the utility program `ttf2pt1`, and is in its own package for licensing reasons.
It will be compiled on installation, so you need a build environment on your system.

# Licensing notes

This product includes software developed by the TTF2PT1 Project and its contributors.

-------------------------


<!-- badges: start -->
[![R-CMD-check](https://github.com/fbertran/Rttf2pt1/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/fbertran/Rttf2pt1/actions/workflows/R-CMD-check.yaml)
[![DOI](https://img.shields.io/badge/doi-10.32614/CRAN.package.Rttf2pt1-blue.svg)](https://doi.org/10.32614/CRAN.package.Rttf2pt1)
[![Lifecycle: stable](https://img.shields.io/badge/lifecycle-stable-green.svg)](https://lifecycle.r-lib.org/articles/stages.html)
[![CRAN status](https://www.r-pkg.org/badges/version/Rttf2pt1)](https://cran.r-project.org/package=Rttf2pt1)
<!-- badges: end -->
